==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/AcsChatChannelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.AcsChatChannelArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * AcsChat channel definition
 * @property channelName The channel name
 * Expected value is 'AcsChatChannel'.
 * @property etag Entity Tag of the resource
 * @property location Specifies the location of the resource.
 */
public data class AcsChatChannelArgs(
    public val channelName: Output<String>,
    public val etag: Output<String>? = null,
    public val location: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.AcsChatChannelArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.AcsChatChannelArgs =
        com.pulumi.azurenative.botservice.inputs.AcsChatChannelArgs.builder()
            .channelName(channelName.applyValue({ args0 -> args0 }))
            .etag(etag?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AcsChatChannelArgs].
 */
@PulumiTagMarker
public class AcsChatChannelArgsBuilder internal constructor() {
    private var channelName: Output<String>? = null

    private var etag: Output<String>? = null

    private var location: Output<String>? = null

    /**
     * @param value The channel name
     * Expected value is 'AcsChatChannel'.
     */
    @JvmName("kygbdvixgjnqrhiv")
    public suspend fun channelName(`value`: Output<String>) {
        this.channelName = value
    }

    /**
     * @param value Entity Tag of the resource
     */
    @JvmName("rocvtlmnxergpygt")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value Specifies the location of the resource.
     */
    @JvmName("lxljarhfgvvjqsbf")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The channel name
     * Expected value is 'AcsChatChannel'.
     */
    @JvmName("rleknfxvawmsrgkc")
    public suspend fun channelName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.channelName = mapped
    }

    /**
     * @param value Entity Tag of the resource
     */
    @JvmName("ilnhjjokvhwogmwy")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value Specifies the location of the resource.
     */
    @JvmName("xkimtjpirmjuldpq")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    internal fun build(): AcsChatChannelArgs = AcsChatChannelArgs(
        channelName = channelName ?: throw PulumiNullFieldException("channelName"),
        etag = etag,
        location = location,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/AcsChatChannelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.AcsChatChannelArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * AcsChat channel definition
 * @property channelName The channel name
 * Expected value is 'AcsChatChannel'.
 * @property etag Entity Tag of the resource
 * @property location Specifies the location of the resource.
 */
public data class AcsChatChannelArgs(
    public val channelName: Output<String>,
    public val etag: Output<String>? = null,
    public val location: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.AcsChatChannelArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.AcsChatChannelArgs =
        com.pulumi.azurenative.botservice.inputs.AcsChatChannelArgs.builder()
            .channelName(channelName.applyValue({ args0 -> args0 }))
            .etag(etag?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AcsChatChannelArgs].
 */
@PulumiTagMarker
public class AcsChatChannelArgsBuilder internal constructor() {
    private var channelName: Output<String>? = null

    private var etag: Output<String>? = null

    private var location: Output<String>? = null

    /**
     * @param value The channel name
     * Expected value is 'AcsChatChannel'.
     */
    @JvmName("tkecwjcehmkfasxw")
    public suspend fun channelName(`value`: Output<String>) {
        this.channelName = value
    }

    /**
     * @param value Entity Tag of the resource
     */
    @JvmName("ywmcmihmvxwgxbve")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value Specifies the location of the resource.
     */
    @JvmName("fqysqapqwfswpqly")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The channel name
     * Expected value is 'AcsChatChannel'.
     */
    @JvmName("qomyctsvtfmyrolp")
    public suspend fun channelName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.channelName = mapped
    }

    /**
     * @param value Entity Tag of the resource
     */
    @JvmName("rtwmkegfmsurwygv")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value Specifies the location of the resource.
     */
    @JvmName("dxfjftpispjrqgci")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    internal fun build(): AcsChatChannelArgs = AcsChatChannelArgs(
        channelName = channelName ?: throw PulumiNullFieldException("channelName"),
        etag = etag,
        location = location,
    )
}
